@@ -11,7 +11,7 @@ import argparse
 import sys
 #from importlib import resources
 def main():
-    parser = argparse.ArgumentParser(description='Quick reference free plotting of bam file')
+    parser = argparse.ArgumentParser(description='access to the gnomad database using selenium')
 
     #requiredNamed = subparsers.add_argument_group('required arguments')
     #parser.add_argument('-c','--chromosome', help='name of chromosome/contig', required=True)
